<?php
/**
 * Plugin Name: Contact Form 7 - Domain Blocker
 * Description: This plugin will block specific email domains in Contact Form 7 submissions.
 * Version: 1.0
 * Author: MOVES
 * Author URI: https://moves.pl
 */

// Check if Contact Form 7 is active
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if ( is_plugin_active( 'contact-form-7/wp-contact-form-7.php' ) )  {

    // Add the filter
    add_filter( 'wpcf7_validate_email*', 'custom_domain_blocker_email_validation_filter', 10, 2 );
    add_filter( 'wpcf7_validate_email', 'custom_domain_blocker_email_validation_filter', 10, 2 );

    function custom_domain_blocker_email_validation_filter( $result, $tag ) {
        if ( 'your-email' == $tag->name ) {
            $blocked_domains = file(plugin_dir_path(__FILE__) . 'blocked_domains.txt', FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);

            $email = sanitize_email($_POST['your-email']);
            if (!is_string($email) || !is_array($blocked_domains)) {
                return $result;
            }

            $email_domain = end(explode("@", $email));

            // Check if the email's domain is in the blocked list
            if (in_array($email_domain, $blocked_domains)) {
                $result->invalidate($tag, "Przepraszamy, nie akceptujemy adresów e-mail z domeny {$email_domain}. Proszę użyć adresu firmowego.");
            }
        }
        return $result;
    }
}
else {
    // Display a notice if Contact Form 7 is not active
    add_action('admin_notices', 'cf7_domain_blocker_error_notice');
    function cf7_domain_blocker_error_notice() {
        echo "<div class='notice notice-error'><p>Contact Form 7 is not activated. Please install and activate Contact Form 7 before using CF7 Domain Blocker.</p></div>";
    }

}

?>
